componenttools.iterate_components_depth_first
=============================================

.. autofunction:: abjad.tools.componenttools.iterate_components_depth_first.iterate_components_depth_first
